Geo Mapper
==========
.. image:: http://travis-ci.org/amiralis/geo-mapper.png

Generate a map of geolocations

.. image:: https://github.com/amiralis/geo-mapper/blob/master/include/map.png


Usage
------------


Installation
------------

To install geomap, simply: ::

    $ pip install geomap